@@ -1,12 +1,12 @@
 import logging
-import time
 import os
+import time
 
 import click
 import yaml
+from betterboto import client as betterboto_client
 
 from servicecatalog_puppet import config, constants
-from betterboto import client as betterboto_client
 
 logger = logging.getLogger(__file__)
 
@@ -53,11 +53,11 @@ def terminate_if_status_is_not_available(
     for r in response.get("ProvisionedProducts", []):
         if r.get("Name") == provisioned_product_name:
             current_status = r.get("Status")
+            logger.info(f"{prefix} :: current status is {current_status}")
             if current_status in ["AVAILABLE", "TAINTED"]:
                 provisioned_product_id = r.get("Id")
                 provisioning_artifact_id = r.get("ProvisioningArtifactId")
             elif current_status in ["UNDER_CHANGE", "PLAN_IN_PROGRESS"]:
-                logger.info(f"{prefix} :: current status is {current_status}")
                 while True:
                     status = (
                         service_catalog.describe_provisioned_product(Id=r.get("Id"))
@@ -80,7 +80,7 @@ def terminate_if_status_is_not_available(
                     f"{prefix} :: terminating as its status is {r.get('Status')}"
                 )
                 terminate_provisioned_product(prefix, service_catalog, r.get("Id"))
-    logger.info(f"{prefix} :: Finished waiting for termination")
+    logger.info(f"{prefix} :: Finished terminate_if_status_is_not_available")
     return provisioned_product_id, provisioning_artifact_id
 
 
@@ -283,7 +283,7 @@ def provision_product(
     product_id,
     provisioning_artifact_id,
     puppet_account_id,
-    path_id,
+    path_name,
     params,
     version,
     should_use_sns,
@@ -304,7 +304,7 @@ def provision_product(
         service_catalog.provision_product(
             ProductId=product_id,
             ProvisioningArtifactId=provisioning_artifact_id,
-            PathId=path_id,
+            PathName=path_name,
             ProvisionedProductName=launch_name,
             ProvisioningParameters=provisioning_parameters,
             Tags=[
@@ -355,7 +355,7 @@ def update_provisioned_product(
     product_id,
     provisioning_artifact_id,
     puppet_account_id,
-    path_id,
+    path_name,
     params,
     version,
     execution,
@@ -370,7 +370,7 @@ def update_provisioned_product(
         service_catalog.update_provisioned_product(
             ProductId=product_id,
             ProvisioningArtifactId=provisioning_artifact_id,
-            PathId=path_id,
+            PathName=path_name,
             ProvisionedProductName=launch_name,
             ProvisioningParameters=provisioning_parameters,
         )
